@@ -6,4 +6,4 @@ if __name__ == "__main__":
     from . import run
     run.runInDirectory(
         pathlib.Path(__file__).parent.parent.parent.parent.parent.joinpath(
-            "temp").joinpath("materials"))
+            "temp").joinpath("materials"), debug=True)
